cmd

package
v0.0.0-...-45ed4f2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 18, 2025 License: Unlicense Imports: 28 Imported by: 0

Documentation

Overview

Package cmd implements the command-line interface for the Caramba framework. It provides various commands for managing agents, running examples, and testing functionality.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckFileExists

func CheckFileExists(filePath string) bool

func Execute

func Execute() error

Execute is the main entry point for the Caramba CLI. It initializes the root command and executes it.

Types

type Manifest

type Manifest struct {
	Name             string
	Image            string
	Command          []string
	Port             int
	SecretName       string
	SecretData       map[string]string
	UsesSharedConfig bool
}

Manifest represents the data passed to the Kubernetes templates.

Jump to